diff --git a/dumux/freeflow/stokes2cni/stokes2cnimodel.hh b/dumux/freeflow/stokes2cni/stokes2cnimodel.hh
index a6fe537f9b8ee4d693eec025af6b5e63cacc1e90..724e663bd5d45df09afe7b6ac624ee52492b2bff 100644
--- a/dumux/freeflow/stokes2cni/stokes2cnimodel.hh
+++ b/dumux/freeflow/stokes2cni/stokes2cnimodel.hh
@@ -94,6 +94,7 @@ class Stokes2cniModel : public Stokes2cModel<TypeTag>
     typedef typename GET_PROP_TYPE(TypeTag, ElementBoundaryTypes) ElementBoundaryTypes;
     typedef typename GET_PROP_TYPE(TypeTag, SolutionVector) SolutionVector;
 
+    typedef typename GET_PROP_TYPE(TypeTag, FluidSystem) FluidSystem;
     typedef typename GET_PROP_TYPE(TypeTag, VolumeVariables) VolumeVariables;
 
 public:
@@ -162,7 +163,9 @@ public:
         writer.attachVertexData(pN, "pg");
         writer.attachVertexData(delP, "delP");
 //        writer.attachVertexData(D, "Dwg");
-        writer.attachVertexData(Xw, "X_gH2O");
+        std::ostringstream outputNameX;
+        outputNameX << "X^" << FluidSystem::componentName(lCompIdx);
+        writer.attachVertexData(Xw, outputNameX.str());
         writer.attachVertexData(T, "temperature");
         writer.attachVertexData(rho, "rhoG");
         writer.attachVertexData(mu, "mu");
diff --git a/dumux/freeflow/stokes2c/stokes2cmodel.hh b/dumux/freeflow/stokes2c/stokes2cmodel.hh
index 7b9e9aab6faf61f51af96218ae267fa297cdf087..544a8749fa565244813c039d82a6d13bba458130 100644
--- a/dumux/freeflow/stokes2c/stokes2cmodel.hh
+++ b/dumux/freeflow/stokes2c/stokes2cmodel.hh
@@ -23,7 +23,7 @@
 /*!
  * \file
  *
  * \brief Adaptation of the box scheme to the compositional Stokes model (with two components).
  */
 #ifndef DUMUX_STOKES2C_MODEL_HH
 #define DUMUX_STOKES2C_MODEL_HH
@@ -36,7 +36,7 @@
 namespace Dumux {
 /*!
  * \ingroup BoxStokes2cModel
- * \brief Adaptation of the BOX scheme to the compositional stokes model.
+ * \brief Adaptation of the BOX scheme to the compositional Stokes model.
  *
  * This model implements an isothermal two-component Stokes flow of a fluid
  * solving a momentum balance, a mass balance and a conservation equation for one component.
@@ -85,6 +85,7 @@ class Stokes2cModel : public StokesModel<TypeTag>
     typedef typename GET_PROP_TYPE(TypeTag, ElementBoundaryTypes) ElementBoundaryTypes;
     typedef typename GET_PROP_TYPE(TypeTag, SolutionVector) SolutionVector;
 
+    typedef typename GET_PROP_TYPE(TypeTag, FluidSystem) FluidSystem;
     typedef typename GET_PROP_TYPE(TypeTag, VolumeVariables) VolumeVariables;
 
 public:
@@ -149,7 +150,9 @@ public:
         }
         writer.attachVertexData(pN, "P");
         writer.attachVertexData(delP, "delP");
-        writer.attachVertexData(Xw, "X_TRAIL");
+        std::ostringstream outputNameX;
+        outputNameX << "X^" << FluidSystem::componentName(lCompIdx);
+        writer.attachVertexData(Xw, outputNameX.str());
         writer.attachVertexData(rho, "rho");
         writer.attachVertexData(mu, "mu");
         writer.attachVertexData(velocity, "v", dim);
@@ -23,7 +23,7 @@
  * \file
  *
- * \brief Adaptation of the box scheme to the compositional Stokes model (with two components).
+ * \brief Adaptation of the box scheme to the two-component Stokes model.
  */
 #ifndef DUMUX_STOKES2C_MODEL_HH